@@ -7,10 +7,7 @@ Usage::
     import boto3
     from mypy_boto3_iot_data import IoTDataPlaneClient
 
-    session = boto3.Session()
-
     client: IoTDataPlaneClient = boto3.client("iot-data")
-    session_client: IoTDataPlaneClient = session.client("iot-data")
     ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
